<?php
/**
 * Zend Framework (http://framework.zend.com/)
 *
 * @link      http://github.com/zendframework/zf2 for the canonical source repository
 * @copyright  Copyright (c) 2005-2014 Zend Technologies USA Inc. (http://www.zend.com)
 * @license    http://framework.zend.com/license/new-bsd     New BSD License
 */

/**
 * CS-Revision: 4.Nov.2013
 */
return array(
    // Zend\Captcha\ReCaptcha
    "Missing captcha fields" => "Chybí pole captcha",
    "Failed to validate captcha" => "Captchu se nepodařilo ověřit",
    "Captcha value is wrong: %value%" => "Hodnota captchy není správná: %value%",

    // Zend\Captcha\Word
    "Empty captcha value" => "Hodnota captcha nebyla zadána",
    "Captcha ID field is missing" => "Chybí pole captcha ID",
    "Captcha value is wrong" => "Hodnota captchy není správná",
);
